@@ -3,11 +3,13 @@ from typing import List
 
 from .teamtv_object import TeamTVObject
 
+
 @dataclass
 class File(object):
     filename: str
     size: int
 
+
 class Exercise(TeamTVObject):
     @property
     def title(self):
@@ -32,7 +34,7 @@ class Exercise(TeamTVObject):
             f"/exercises/{self.exercise_id}/initVideoUpload",
             dict(
                 files=[dict(filename=file.filename, size=file.size) for file in files]
-            )
+            ),
         )
         self._video_id = video_id
         return video_id
@@ -41,16 +43,14 @@ class Exercise(TeamTVObject):
         self._requester.request(
             "POST",
             f"/exercises/{self.exercise_id}/setVariables",
-            dict(
-                variables=variables
-            )
+            dict(variables=variables),
         )
 
     def __repr__(self):
         return f'<Exercise exercise_id={self.exercise_id} title="{self.title}" video_id={self.video_id}>'
 
     def _use_attributes(self, attributes: dict):
-        self._exercise_id = attributes['exerciseId']
-        self._title = attributes['title']
-        self._video_id = attributes.get('videoId')
-        self._tags = attributes.get('tags', {})
+        self._exercise_id = attributes["exerciseId"]
+        self._title = attributes["title"]
+        self._video_id = attributes.get("videoId")
+        self._tags = attributes.get("tags", {})
